==> webkit2gtk_2.36.0.orig.tar.xz: webkitgtk-2.36.0/Source/WebKit/Shared/PushMessageForTesting.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/URL.h>
#include <wtf/text/WTFString.h>

namespace WebKit::WebPushD {

struct PushMessageForTesting {
    template<class Encoder> void encode(Encoder&) const;
    template<class Decoder> static std::optional<PushMessageForTesting> decode(Decoder&);

    String targetAppCodeSigningIdentifier;
    URL registrationURL;
    String message;
};

template<class Encoder>
void PushMessageForTesting::encode(Encoder& encoder) const
{
    encoder << targetAppCodeSigningIdentifier << registrationURL << message;
}

template<class Decoder>
std::optional<PushMessageForTesting> PushMessageForTesting::decode(Decoder& decoder)
{
    std::optional<String> targetAppCodeSigningIdentifier;
    decoder >> targetAppCodeSigningIdentifier;
    if (!targetAppCodeSigningIdentifier)
        return std::nullopt;

    std::optional<URL> registrationURL;
    decoder >> registrationURL;
    if (!registrationURL)
        return std::nullopt;

    std::optional<String> message;
    decoder >> message;
    if (!message)
        return std::nullopt;

    return { {
        WTFMove(*targetAppCodeSigningIdentifier),
        WTFMove(*registrationURL),
        WTFMove(*message),
    } };
}

} // namespace WebKit::WebPushD

==> webkit2gtk_2.41.91.orig.tar.xz: webkitgtk-2.41.91/Source/WebKit/Shared/PushMessageForTesting.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/URL.h>
#include <wtf/text/WTFString.h>

namespace WebKit::WebPushD {

struct PushMessageForTesting {
    template<class Encoder> void encode(Encoder&) const;
    template<class Decoder> static std::optional<PushMessageForTesting> decode(Decoder&);

    String targetAppCodeSigningIdentifier;
    String pushPartitionString;
    URL registrationURL;
    String message;
};

template<class Encoder>
void PushMessageForTesting::encode(Encoder& encoder) const
{
    encoder << targetAppCodeSigningIdentifier << pushPartitionString << registrationURL << message;
}

template<class Decoder>
std::optional<PushMessageForTesting> PushMessageForTesting::decode(Decoder& decoder)
{
    std::optional<String> targetAppCodeSigningIdentifier;
    decoder >> targetAppCodeSigningIdentifier;
    if (!targetAppCodeSigningIdentifier)
        return std::nullopt;

    std::optional<String> pushPartitionString;
    decoder >> pushPartitionString;
    if (!pushPartitionString)
        return std::nullopt;

    std::optional<URL> registrationURL;
    decoder >> registrationURL;
    if (!registrationURL)
        return std::nullopt;

    std::optional<String> message;
    decoder >> message;
    if (!message)
        return std::nullopt;

    return { {
        WTFMove(*targetAppCodeSigningIdentifier),
        WTFMove(*pushPartitionString),
        WTFMove(*registrationURL),
        WTFMove(*message),
    } };
}

} // namespace WebKit::WebPushD
